#!/bin/bash
# ----------------------------------------------------------------------------------
#
#    Shukllachiska Kichwa del Ecuador, hunspell format dictionary generator
#    Copyright (C) 2009 Arno Teigseth, Henry David Lara
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program. See LICENSE.txt. If not, see <http://www.gnu.org/licenses/>.
#
#    The author(s) can be contacted at arno at teigseth dot no
#
# ----------------------------------------------------------------------------------
# 
# This is *NOT* the .dic file, but a script to generate such a file, taking the
# words from qu_EC.dic.MASTER. See the file qu_EC.dic.MASTER for dictionary creation rules.
#
# Generate qu_EC.dic file

# Variables
TMPFILE=/tmp/quiwork
VFILE=/tmp/quiworkVerbs
OFILE=/tmp/quiworkOther
OUTFILE=qu_EC.dic

#Functions
 variant () # Create infix variants
 {
   VERB=`echo $1 |sed -e 's/\/\/.*$//'`  # Remove trailing // and whatever.

   # OUT Base verb -na
   echo ${VERB}//v
   
   STEM=`echo $VERB |sed s/na$//`      # Stem without -na
   RULES=`echo $1 |sed -e 's/.*\/\///'` # Remove stem and //
   
   # OUT -ri- infix and variants
   if [[ $RULES == *r* ]] 
   then 
      echo ${STEM}rina//v

      # OUT -rimu- infix
	   if [[ $RULES == *,* ]] 	
	   then 
	      echo ${STEM}rimuna//v
	   fi

      # OUT -richi- infix
      if [[ $RULES == *h* ]] 
      then 
         echo ${STEM}richina//v
		fi

	   # OUT -riku- infix and variants
	   if [[ $RULES == *-* ]] 
	   then 
	      echo ${STEM}rikuna//v
	   fi

   fi

   # OUT -kri- infix and variants
   if [[ $RULES == *\>* ]] 
   then 
      echo ${STEM}krina//v
   fi

   # OUT -ra- infix and variants
   if [[ $RULES == *+* ]] 
   then 
      echo ${STEM}rana//v
   fi

   # OUT -ku- infix and variants
   if [[ $RULES == *-* ]] 
   then 
      echo ${STEM}kuna//v
      echo ${STEM}nakuna//v
   fi

   # OUT -mu- infix and variants
   if [[ $RULES == *,* ]] 
   then 
      echo ${STEM}muna//v

      # OUT -muwa- infix
      if [[ $RULES == *w* ]] 
      then 
         echo ${STEM}muwana//v
      fi

      # OUT -muku- infix
	   if [[ $RULES == *-* ]] 
	   then 
	      echo ${STEM}mukuna//v
	      echo ${STEM}namukuna//v
	   fi
   fi

   # OUT -wa- infix and variants
   if [[ $RULES == *w* ]] 
   then 
      echo ${STEM}wana//v
   fi

   # OUT -chi- infix and variants
   if [[ $RULES == *h* ]] 
   then 
      echo ${STEM}china//v

      # OUT -chiwa- infix
      if [[ $RULES == *w* ]] 
      then 
         echo ${STEM}chiwana//v
      fi

      # OUT -chiku- infix
      if [[ $RULES == *-* ]] 
      then 
         echo ${STEM}chikuna//v
         echo ${STEM}chinakuna//v
      fi
   fi
 }
 
#  Prep: remove comments and rtrim whitespace
cat qu_EC.dic.MASTER |sed s/#.*$// |sed s/" "*$// |grep -v ^$ > $TMPFILE 

# Find verbs
cat $TMPFILE | grep v$ > $VFILE

# Find other words
echo Writing non-verbs...
cat $TMPFILE | grep -v v$ > $OFILE

# Prep outfile 
rm $TMPFILE

# Put infixes onto verbs, into outfile.
for i in `cat $VFILE`; do
 echo Creating variants of $i
 variant $i >> $TMPFILE; # Create variants of verb, according to the rules
done

# Create outfile
cat $OFILE >> $TMPFILE

# Count it
cat $TMPFILE |grep -c $ > $OUTFILE

# Sort it
cat $TMPFILE |sort >> $OUTFILE


#Clean up
#rm $TMPFILE
#rm $VFILE
#rm $OFILE

